use crate::{physics::Polar, Camera, Doodad, Sprite, Spriteable};
use cgmath::Deg;

pub struct System {
	bodies: Vec<Doodad>,
}

impl System {
	pub fn new() -> Self {
		let mut s = System { bodies: Vec::new() };

		s.bodies.push(Doodad {
			pos: (0.0, 0.0).into(),
			sprite: "a0".to_owned(),
		});

		s.bodies.push(Doodad {
			pos: Polar {
				center: (0.0, 0.0).into(),
				radius: 300.0,
				angle: Deg { 0: 31.0 },
			}
			.to_cartesian(),
			sprite: "earth".to_owned(),
		});

		s.bodies.push(Doodad {
			pos: (1000.0, 1000.0).into(),
			sprite: "small".to_owned(),
		});

		return s;
	}

	pub fn sprites(&self, camera: &Camera) -> Vec<Sprite> {
		return self.bodies.iter().map(|x| x.sprite(camera)).collect();
	}
}
